@@ -3,7 +3,7 @@
 /*
  *  Author: Michael Roth <mroth@nessie.de>
  *
- *  Copyright (c) 2004, 2005 Michael Roth <mroth@nessie.de>
+ *  Copyright (c) 2004, 2005, 2006 Michael Roth <mroth@nessie.de>
  *
  *  Permission is hereby granted, free of charge, to any person 
  *  obtaining a copy of this software and associated documentation
@@ -58,7 +58,7 @@
 
 #define CB_DATA(ptr)		CAST(CB_Data *, (ptr))
 
-#define KEY(ptr, id)		( CAST(void*,(ptr)) + (id) )
+#define KEY(ptr, id)		CAST( void*, CAST(char*,(ptr))+(id) )
 
 #define KEY_KEY2VALUE_TABLE(p)	KEY((p), 1)
 #define KEY_FUNCTION_TABLE(p)	KEY((p), 2)
@@ -452,7 +452,7 @@ FUNC( l_sqlite3_bind_parameter_name )
 FUNC( l_sqlite3_bind_parameter_name_x )
 {
   const char * name = sqlite3_bind_parameter_name(checkstmt_stmt(L, 1), checkint(L, 2));
-  if (name)
+  if (name && *name)
     lua_pushstring(L, name + 1);	/* Ignore leading '$' or ':' */
   else
     lua_pushnil(L);
