@@ -437,15 +437,36 @@ end
 
 
 function bug:test_1()
-   self.db:exec("CREATE TABLE test (id INTEGER PRIMARY KEY, value TEXT)")
-   
-   local query = assert_table( self.db:prepare("SELECT id FROM test WHERE value=?") )
-   
-   assert_table ( query:bind("1") )
-   assert_nil   ( query:first_cols() )
-   assert_table ( query:bind("2") )
-   assert_nil   ( query:first_cols() )
+  self.db:exec("CREATE TABLE test (id INTEGER PRIMARY KEY, value TEXT)")
+  
+  local query = assert_table( self.db:prepare("SELECT id FROM test WHERE value=?") )
+  
+  assert_table ( query:bind("1") )
+  assert_nil   ( query:first_cols() )
+  assert_table ( query:bind("2") )
+  assert_nil   ( query:first_cols() )
 end
 
 
+function bug:test_nils()   -- appeared in lua-5.1 (holes in arrays)
+  local function check(arg1, arg2, arg3, arg4, arg5)
+    assert_equal(1, arg1)
+    assert_equal(2, arg2)
+    assert_nil(arg3)
+    assert_equal(4, arg4)
+    assert_nil(arg5)
+  end
+  
+  self.db:set_function("test_nils", 5, function(arg1, arg2, arg3, arg4, arg5)
+    check(arg1, arg2, arg3, arg4, arg5)
+  end)
+  
+  assert_table( self.db:exec([[ SELECT test_nils(1, 2, NULL, 4, NULL) ]]) )
+  
+  local arg1, arg2, arg3, arg4, arg5 = self.db:first_cols([[ SELECT 1, 2, NULL, 4, NULL ]])
+  check(arg1, arg2, arg3, arg4, arg5)
+  
+  local row = assert_table( self.db:first_irow([[ SELECT 1, 2, NULL, 4, NULL ]]) )
+  check(row[1], row[2], row[3], row[4], row[5])
+end
 
